.. littlemcmc documentation master file, created by
   sphinx-quickstart on Sat Dec 14 22:49:04 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

LittleMCMC
==========

.. image:: https://github.com/eigenfoo/littlemcmc/workflows/tests/badge.svg
    :target: https://github.com/eigenfoo/littlemcmc
.. image:: https://github.com/eigenfoo/littlemcmc/workflows/lint/badge.svg
    :target: https://github.com/eigenfoo/littlemcmc
.. image:: https://codecov.io/gh/eigenfoo/littlemcmc/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/eigenfoo/littlemcmc
.. image:: https://readthedocs.org/projects/littlemcmc/badge/?version=latest
    :target: https://littlemcmc.readthedocs.io/en/latest/?badge=latest
.. image:: https://img.shields.io/github/license/eigenfoo/littlemcmc
    :target: https://github.com/eigenfoo/littlemcmc/blob/master/LICENSE.littlemcmc.txt

.. raw:: html

    <div style="color: #555; border-left: 8px solid #ddd; padding: 5px 15px 8px; margin: 20px 0">
    <strong>littlemcmc</strong> &nbsp; &nbsp;
    /lɪtəl ɛm si ɛm si/ &nbsp; &nbsp;
    <i>noun</i><br><br>
    A lightweight and performant implementation of HMC and NUTS in Python, spun
    out of <a href="https://github.com/pymc-devs">the PyMC project</a>. Not to
    be confused with <a href="https://github.com/ColCarroll/minimc">minimc</a>.
    </div>

.. toctree::
   :maxdepth: 2
   :caption: Contents

   install
   tutorials/quickstart
   tutorials/framework_cookbook
   api
   developer_guide
